@@ -59,6 +59,9 @@ struct _PersonalPhotoFramePrivate
 	gint slideshowDuration;
 	gboolean slideshowRandom;
 	gboolean showSlideshowControls;
+	gint widgetSize;
+	gint actualSize;
+	
 	gboolean isPressed;
 	gboolean leftArrowPressed;
 	gboolean rightArrowPressed;
@@ -126,7 +129,7 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
 
 		self->priv->singleMode = g_key_file_get_boolean (keyFile, "config", "singleMode", &error);
 		if (error) {
-			self->priv->singleMode = TRUE;
+			self->priv->singleMode = FALSE;
 			g_error_free (error);
 			error = NULL;
 		}
@@ -138,9 +141,11 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
         }
 		self->priv->slideshowDirname = g_key_file_get_string (keyFile, "config", "slideshowDirname", &error);
 		if (error) {
-			self->priv->slideshowDirname = "";
+			gchar *string = g_build_path ("/", HOME_DIR, "MyDocs/.images", NULL);
+			self->priv->slideshowDirname = g_strdup (string);
 			g_error_free (error);
 			error = NULL;
+			g_free (string);
 		}
 		self->priv->slideshowNum = g_key_file_get_integer (keyFile, "config", "slideshowNum", &error);
 		if (error) {
@@ -150,7 +155,7 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
 		}
 		self->priv->slideshowDuration = g_key_file_get_integer (keyFile, "config", "slideshowDuration", &error);
 		if (error) {
-			self->priv->slideshowDuration = 0;
+			self->priv->slideshowDuration = 3;
 			g_error_free (error);
 			error = NULL;
 		}
@@ -166,16 +171,33 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
 			g_error_free (error);
 			error = NULL;
 		}
+		self->priv->widgetSize = g_key_file_get_integer (keyFile, "config", "widgetSize", &error);
+		if (error) {
+			self->priv->widgetSize = 1;
+			g_error_free (error);
+			error = NULL;
+		}
     } else {
-		self->priv->singleMode = TRUE;
+		gchar *string = g_build_path ("/", HOME_DIR, "MyDocs/.images", NULL);
+		self->priv->singleMode = FALSE;
         self->priv->singleFilename = "/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png";
-		self->priv->slideshowDirname = "";
+		self->priv->slideshowDirname = g_strdup (string);
 		self->priv->slideshowNum = 0;
-		self->priv->slideshowDuration = 0;
+		self->priv->slideshowDuration = 3;
 		self->priv->slideshowRandom = FALSE;
 		self->priv->showSlideshowControls = TRUE;
+		self->priv->widgetSize = 1;
+		g_free (string);
     }
 	
+	if (self->priv->widgetSize == 0) {
+		self->priv->actualSize = 200;
+	} else if (self->priv->widgetSize ==1) {
+		self->priv->actualSize = 315;
+	} else {
+		self->priv->actualSize = 420;
+	}
+	
     g_key_file_free (keyFile);
     g_free (filename);
 }
@@ -198,6 +220,7 @@ void personal_photo_frame_write_settings (PersonalPhotoFrame *self)
 	g_key_file_set_integer (keyFile, "config", "slideshowDuration", self->priv->slideshowDuration);
 	g_key_file_set_boolean (keyFile, "config", "slideshowRandom", self->priv->slideshowRandom);
 	g_key_file_set_boolean (keyFile, "config", "showSlideshowControls", self->priv->showSlideshowControls);
+	g_key_file_set_integer (keyFile, "config", "widgetSize", self->priv->widgetSize);
 	
 	filename = g_strconcat (HOME_DIR, "/.personal_photo_frame", NULL);
 	fileData = g_key_file_to_data (keyFile, &size, NULL);
@@ -217,11 +240,11 @@ void personal_photo_frame_button_press (GtkWidget *widget, GdkEventButton *event
 		gdouble x_coord, y_coord;
 	
 		if (gdk_event_get_coords (event, &x_coord, &y_coord)) {
-			if (y_coord > 310.0 - 48.0) {
-				if (x_coord > 310.0 - 48.0) {
+			if (y_coord > self->priv->actualSize - 53.0) {
+				if (x_coord > self->priv->actualSize - 53.0) {
 					openImage = FALSE;
 					self->priv->rightArrowPressed = TRUE;
-				} else if (x_coord < 5.0 + 48.0) {
+				} else if (x_coord < 53.0) {
 					openImage = FALSE;
 					self->priv->leftArrowPressed = TRUE;
 				}
@@ -247,13 +270,13 @@ void personal_photo_frame_button_release (GtkWidget *widget, GdkEventButton *eve
 		gdouble x_coord, y_coord;
 	
 		if (gdk_event_get_coords (event, &x_coord, &y_coord)) {
-			if (y_coord > 310.0 - 48.0) {
-				if (x_coord > 310.0 - 48.0) {
+			if (y_coord > self->priv->actualSize - 53.0) {
+				if (x_coord > self->priv->actualSize - 53.0) {
 					personal_photo_frame_update_content (self);
 					personal_photo_frame_remove_timers (self);
 					personal_photo_frame_add_timers (self);
 					openImage = FALSE;
-				} else if (x_coord < 5.0 + 48.0) {
+				} else if (x_coord < 53.0) {
 					self->priv->slideshowNum-=2;
 					personal_photo_frame_update_content (self);
 					personal_photo_frame_remove_timers (self);
@@ -295,7 +318,7 @@ void personal_photo_frame_content_create (PersonalPhotoFrame *self)
 
 	gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), self->priv->event, TRUE, TRUE, 0);
 	
-	self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 305, 305);
+	self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize - 10, self->priv->actualSize - 10);
 	gdk_pixbuf_fill (self->priv->image, 0x00000000);
 	self->priv->backButton = gdk_pixbuf_new_from_file ("/usr/share/icons/hicolor/48x48/hildon/general_back.png", NULL);
 	self->priv->forwardButton = gdk_pixbuf_new_from_file ("/usr/share/icons/hicolor/48x48/hildon/general_forward.png", NULL);
@@ -324,7 +347,7 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 
 	if (self->priv->singleMode) {
 		g_object_unref (self->priv->image);
-		self->priv->image = gdk_pixbuf_new_from_file_at_scale (self->priv->singleFilename, 305, 305, TRUE, NULL);
+		self->priv->image = gdk_pixbuf_new_from_file_at_scale (self->priv->singleFilename, self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
 	} else {
 		GDir *dir = g_dir_open (self->priv->slideshowDirname, 0, NULL);
 		
@@ -344,13 +367,13 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 					looped++;
 					g_dir_rewind (dir);
 					g_object_unref (self->priv->image);
-					self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 305, 305);
+					self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize - 10, self->priv->actualSize - 10);
 					gdk_pixbuf_fill (self->priv->image, 0x00000000);
 					gtk_widget_queue_draw (self);
 				} else {
 					self->priv->slideshowFilename = g_strconcat (self->priv->slideshowDirname, "/", filename, NULL);
 
-					GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->slideshowFilename, 305, 305, TRUE, NULL);
+					GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->slideshowFilename, self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
 					if (pixbuf) {
 						g_object_unref (self->priv->image);
 						self->priv->image = gdk_pixbuf_copy (pixbuf);
@@ -365,7 +388,7 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 			g_dir_close (dir);
 		} else {
 			g_object_unref (self->priv->image);
-			self->priv->image = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png", 305, 305, TRUE, NULL);
+			self->priv->image = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png", self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
 		}
 	}
 }
@@ -419,6 +442,17 @@ void personal_photo_frame_settings (HDHomePluginItem *hitem, PersonalPhotoFrame
 	self->priv->singleModeBox = gtk_vbox_new (FALSE, 0);
 	self->priv->slideshowModeBox = gtk_vbox_new (FALSE, 0);
 	
+	GtkWidget *sizeSelector = hildon_touch_selector_new_text ();
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), "small");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), "medium");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), "large");
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (sizeSelector), 0, self->priv->widgetSize);
+	
+	GtkWidget *widgetSize = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
+	hildon_button_set_title (HILDON_BUTTON (widgetSize), "Display size");
+	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (widgetSize), HILDON_TOUCH_SELECTOR (sizeSelector));
+	gtk_box_pack_start (GTK_BOX (content_area), widgetSize, FALSE, FALSE, 0);
+	
 	GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
 	GtkWidget *singleModeToggle = hildon_gtk_radio_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, NULL);
 	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (singleModeToggle), FALSE);
@@ -485,6 +519,18 @@ void personal_photo_frame_settings (HDHomePluginItem *hitem, PersonalPhotoFrame
 		self->priv->slideshowDuration = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
 		self->priv->slideshowRandom = hildon_check_button_get_active (HILDON_CHECK_BUTTON (slideshowRandom));
 		self->priv->showSlideshowControls = hildon_check_button_get_active (HILDON_CHECK_BUTTON (showSlideshowControls));
+		self->priv->widgetSize = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (sizeSelector), 0);
+		
+		if (self->priv->widgetSize == 0) {
+			self->priv->actualSize = 200;
+		} else if (self->priv->widgetSize ==1) {
+			self->priv->actualSize = 315;
+		} else {
+			self->priv->actualSize = 420;
+		}
+
+		gtk_widget_set_size_request (GTK_WIDGET (self), self->priv->actualSize, self->priv->actualSize);
+		gtk_window_resize (GTK_WINDOW (self), self->priv->actualSize, self->priv->actualSize);
 		
 		if (!g_str_equal (compare, self->priv->slideshowDirname)) {
 			self->priv->slideshowNum = 0;
@@ -516,6 +562,17 @@ static void personal_photo_frame_check_desktop (GObject *gobject, GParamSpec *ps
 			}
 		}
 	}
+	
+	if (self->priv->widgetSize == 0) {
+		self->priv->actualSize = 200;
+	} else if (self->priv->widgetSize ==1) {
+		self->priv->actualSize = 315;
+	} else {
+		self->priv->actualSize = 420;
+	}
+
+	gtk_widget_set_size_request (GTK_WIDGET (self), self->priv->actualSize, self->priv->actualSize);
+	gtk_window_resize (GTK_WINDOW (self), self->priv->actualSize, self->priv->actualSize);
 }
 
 static void personal_photo_frame_dispose (GObject *object)
@@ -536,6 +593,7 @@ static void personal_photo_frame_finalize (GObject *object)
 	}
 	g_object_unref (self->priv->forwardButton);
 	g_object_unref (self->priv->backButton);
+	g_object_unref (self->priv->image);
 	
 	personal_photo_frame_write_settings (self);
 
@@ -603,8 +661,8 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 	
 	gint pixbufWidth=gdk_pixbuf_get_width(self->priv->image);
 	gint pixbufHeight=gdk_pixbuf_get_height(self->priv->image);
-	gint leftPos = 5 + ((305 - pixbufWidth)/2);
-	gint topPos = 5 + ((305 - pixbufHeight)/2);
+	gint leftPos = 5 + ((width - 10 - pixbufWidth)/2);
+	gint topPos = 5 + ((height - 10 - pixbufHeight)/2);
 	gdk_cairo_set_source_pixbuf (cr, self->priv->image, leftPos, topPos);
 	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
 	if (!self->priv->isPressed) {
@@ -628,17 +686,17 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 	
 	if (!self->priv->singleMode && self->priv->showSlideshowControls) {
 		cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
-		gdk_cairo_set_source_pixbuf (cr, self->priv->backButton, 5, 310 - 48);
+		gdk_cairo_set_source_pixbuf (cr, self->priv->backButton, 5, height - 53);
 		cairo_paint_with_alpha (cr, 0.5);
 		
-		gdk_cairo_set_source_pixbuf (cr, self->priv->forwardButton, 310 - 48, 310 - 48);
+		gdk_cairo_set_source_pixbuf (cr, self->priv->forwardButton, width - 53, height - 53);
 		cairo_paint_with_alpha (cr, 0.5);
 		
-		cairo_move_to (cr, 5, 310 - 48);
-		cairo_line_to (cr, 5, 310);
-		cairo_line_to (cr, 5 + 48, 310);
-		cairo_line_to (cr, 5 + 48, 310 - 48);
-		cairo_line_to (cr, 5, 310 - 48);
+		cairo_move_to (cr, 5, height - 53);
+		cairo_line_to (cr, 5, height - 5);
+		cairo_line_to (cr, 5 + 48, height - 5);
+		cairo_line_to (cr, 5 + 48, height - 53);
+		cairo_line_to (cr, 5, height - 53);
 		
 		if (self->priv->leftArrowPressed) {
 			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
@@ -651,11 +709,11 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 		cairo_set_line_width (cr, 1);
 		cairo_stroke (cr);
 		
-		cairo_move_to (cr, 310 - 48, 310 - 48);
-		cairo_line_to (cr, 310 - 48, 310);
-		cairo_line_to (cr, 310, 310);
-		cairo_line_to (cr, 310, 310 - 48);
-		cairo_line_to (cr, 310 - 48, 310 - 48);
+		cairo_move_to (cr, width - 53, height - 53);
+		cairo_line_to (cr, width - 53, height - 5);
+		cairo_line_to (cr, width - 5, height - 5);
+		cairo_line_to (cr, width - 5, height - 53);
+		cairo_line_to (cr, width - 53, height - 53);
 		
 		if (self->priv->rightArrowPressed) {
 			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
@@ -705,17 +763,17 @@ static void personal_photo_frame_init (PersonalPhotoFrame *self)
 	hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_photo_frame_settings), self);
 
-	gtk_window_set_default_size (GTK_WINDOW (self), 315, 315);
+	gtk_window_set_default_size (GTK_WINDOW (self), 200, 200);
 	
 	self->priv->homeWidget = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self), self->priv->homeWidget);
 	gtk_widget_show (self->priv->homeWidget);
 
 	GdkGeometry hints;
-	hints.min_width = 315;
-	hints.min_height = 315;
-	hints.max_width = 315;
-	hints.max_height = 315;
+	hints.min_width = 200;
+	hints.min_height = 200;
+	hints.max_width = 420;
+	hints.max_height = 420;
 	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
 	
 	personal_photo_frame_read_settings (self);
